@@ -13,30 +13,44 @@ const aliases = new Map([
 
 const validTargets = new Set([
   'android',
+  'bun',
   'chrome',
+  'deno',
   'edge',
   'electron',
   'firefox',
+  'hermes',
   'ie',
   'ios',
   'node',
+  'oculus',
   'opera',
   'opera_mobile',
   'phantom',
+  'rhino',
   'safari',
   'samsung',
 ]);
 
+const toLowerKeys = function (object) {
+  return Object.entries(object).reduce((accumulator, [key, value]) => {
+    accumulator[key.toLowerCase()] = value;
+    return accumulator;
+  }, {});
+};
+
 module.exports = function (targets) {
-  if (typeof targets !== 'object' || Array.isArray(targets)) {
-    targets = { browsers: targets };
-  }
+  const { browsers, esmodules, node, ...rest } = (typeof targets != 'object' || Array.isArray(targets))
+    ? { browsers: targets } : toLowerKeys(targets);
 
-  const { browsers, esmodules, node, ...rest } = targets;
   const list = Object.entries(rest);
 
   if (browsers) {
-    list.push(...browserslist(browsers).map(it => it.split(' ')));
+    if (typeof browsers == 'string' || Array.isArray(browsers)) {
+      list.push(...browserslist(browsers).map(it => it.split(' ')));
+    } else {
+      list.push(...Object.entries(browsers));
+    }
   }
   if (esmodules) {
     list.push(...Object.entries(external.modules));
