@@ -1,5 +1,6 @@
 'use strict';
 var $ = require('../internals/export');
+var call = require('../internals/function-call');
 var toObject = require('../internals/to-object');
 var toPrimitive = require('../internals/to-primitive');
 var toISOString = require('../internals/date-to-iso-string');
@@ -8,17 +9,17 @@ var fails = require('../internals/fails');
 
 var FORCED = fails(function () {
   return new Date(NaN).toJSON() !== null
-    || Date.prototype.toJSON.call({ toISOString: function () { return 1; } }) !== 1;
+    || call(Date.prototype.toJSON, { toISOString: function () { return 1; } }) !== 1;
 });
 
 // `Date.prototype.toJSON` method
 // https://tc39.es/ecma262/#sec-date.prototype.tojson
 $({ target: 'Date', proto: true, forced: FORCED }, {
-  // eslint-disable-next-line no-unused-vars
+  // eslint-disable-next-line no-unused-vars -- required for `.length`
   toJSON: function toJSON(key) {
     var O = toObject(this);
-    var pv = toPrimitive(O);
+    var pv = toPrimitive(O, 'number');
     return typeof pv == 'number' && !isFinite(pv) ? null :
-      (!('toISOString' in O) && classof(O) == 'Date') ? toISOString.call(O) : O.toISOString();
+      (!('toISOString' in O) && classof(O) == 'Date') ? call(toISOString, O) : O.toISOString();
   }
 });
