@@ -1,20 +1,21 @@
 'use strict';
 var $ = require('../internals/export');
-var IS_PURE = require('../internals/is-pure');
+var aCallable = require('../internals/a-callable');
 var anObject = require('../internals/an-object');
-var aFunction = require('../internals/a-function');
 var getSetIterator = require('../internals/get-set-iterator');
 var iterate = require('../internals/iterate');
 
+var $TypeError = TypeError;
+
 // `Set.prototype.reduce` method
 // https://github.com/tc39/proposal-collection-methods
-$({ target: 'Set', proto: true, real: true, forced: IS_PURE }, {
+$({ target: 'Set', proto: true, real: true, forced: true }, {
   reduce: function reduce(callbackfn /* , initialValue */) {
     var set = anObject(this);
     var iterator = getSetIterator(set);
     var noInitial = arguments.length < 2;
     var accumulator = noInitial ? undefined : arguments[1];
-    aFunction(callbackfn);
+    aCallable(callbackfn);
     iterate(iterator, function (value) {
       if (noInitial) {
         noInitial = false;
@@ -22,8 +23,8 @@ $({ target: 'Set', proto: true, real: true, forced: IS_PURE }, {
       } else {
         accumulator = callbackfn(accumulator, value, value, set);
       }
-    }, undefined, false, true);
-    if (noInitial) throw TypeError('Reduce of empty set with no initial value');
+    }, { IS_ITERATOR: true });
+    if (noInitial) throw $TypeError('Reduce of empty set with no initial value');
     return accumulator;
   }
 });
